/****************************************************************************
** Meta object code from reading C++ file 'identitymanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kidentitymanagement-17.04.3/src/identitymanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identitymanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KIdentityManagement__IdentityManager_t {
    QByteArrayData data[12];
    char stringdata0[157];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIdentityManagement__IdentityManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIdentityManagement__IdentityManager_t qt_meta_stringdata_KIdentityManagement__IdentityManager = {
    {
QT_MOC_LITERAL(0, 0, 36), // "KIdentityManagement::Identity..."
QT_MOC_LITERAL(1, 37, 7), // "changed"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 4), // "uoid"
QT_MOC_LITERAL(4, 51, 29), // "KIdentityManagement::Identity"
QT_MOC_LITERAL(5, 81, 5), // "ident"
QT_MOC_LITERAL(6, 87, 7), // "deleted"
QT_MOC_LITERAL(7, 95, 5), // "added"
QT_MOC_LITERAL(8, 101, 17), // "identitiesChanged"
QT_MOC_LITERAL(9, 119, 2), // "id"
QT_MOC_LITERAL(10, 122, 12), // "slotRollback"
QT_MOC_LITERAL(11, 135, 21) // "slotIdentitiesChanged"

    },
    "KIdentityManagement::IdentityManager\0"
    "changed\0\0uoid\0KIdentityManagement::Identity\0"
    "ident\0deleted\0added\0identitiesChanged\0"
    "id\0slotRollback\0slotIdentitiesChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIdentityManagement__IdentityManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,
       1,    1,   55,    2, 0x06 /* Public */,
       1,    1,   58,    2, 0x06 /* Public */,
       6,    1,   61,    2, 0x06 /* Public */,
       7,    1,   64,    2, 0x06 /* Public */,
       8,    1,   67,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   70,    2, 0x09 /* Protected */,
      11,    1,   71,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    3,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::UInt,    3,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::QString,    9,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,

       0        // eod
};

void KIdentityManagement::IdentityManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IdentityManager *_t = static_cast<IdentityManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->changed((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 2: _t->changed((*reinterpret_cast< const KIdentityManagement::Identity(*)>(_a[1]))); break;
        case 3: _t->deleted((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 4: _t->added((*reinterpret_cast< const KIdentityManagement::Identity(*)>(_a[1]))); break;
        case 5: _t->identitiesChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->slotRollback(); break;
        case 7: _t->d->slotIdentitiesChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (IdentityManager::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&IdentityManager::changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (IdentityManager::*_t)(uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&IdentityManager::changed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (IdentityManager::*_t)(const KIdentityManagement::Identity & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&IdentityManager::changed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (IdentityManager::*_t)(uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&IdentityManager::deleted)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (IdentityManager::*_t)(const KIdentityManagement::Identity & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&IdentityManager::added)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (IdentityManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&IdentityManager::identitiesChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject KIdentityManagement::IdentityManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KIdentityManagement__IdentityManager.data,
      qt_meta_data_KIdentityManagement__IdentityManager,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KIdentityManagement::IdentityManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIdentityManagement::IdentityManager::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KIdentityManagement__IdentityManager.stringdata0))
        return static_cast<void*>(const_cast< IdentityManager*>(this));
    return QObject::qt_metacast(_clname);
}

int KIdentityManagement::IdentityManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KIdentityManagement::IdentityManager::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void KIdentityManagement::IdentityManager::changed(uint _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KIdentityManagement::IdentityManager::changed(const KIdentityManagement::Identity & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KIdentityManagement::IdentityManager::deleted(uint _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KIdentityManagement::IdentityManager::added(const KIdentityManagement::Identity & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KIdentityManagement::IdentityManager::identitiesChanged(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_END_MOC_NAMESPACE
