/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a identitymanageradaptor -i identitymanager.h -l KIdentityManagement::IdentityManager /usr/src/ports/kf5-kidentitymanagement/kf5-kidentitymanagement-17.04.3-1.x86_64/src/kidentitymanagement-17.04.3/src/org.kde.pim.IdentityManager.xml
 *
 * qdbusxml2cpp is Copyright (C) 2016 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "identitymanageradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class IdentityManagerAdaptor
 */

IdentityManagerAdaptor::IdentityManagerAdaptor(KIdentityManagement::IdentityManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

IdentityManagerAdaptor::~IdentityManagerAdaptor()
{
    // destructor
}


#include "identitymanageradaptor.moc"
